@@ -95,7 +95,7 @@ extern int method;         /* compression method */
 #  define EXTERN(type, array)  extern type * near array
 #  define DECLARE(type, array, size)  type * near array
 #  define ALLOC(type, array, size) { \
-      array = (type*)fcalloc((unsigned)(((size)+1L)/2), 2*sizeof(type)); \
+      array = (type*)fcalloc((size_t)(((size)+1L)/2), 2*sizeof(type)); \
       if (array == NULL) error("insufficient memory"); \
    }
 #  define FREE(array) {if (array != NULL) fcfree(array), array=NULL;}
